@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -20,6 +20,10 @@ class CountdownTooltip : public DWidget
 public:
     explicit CountdownTooltip(DWidget *parent = 0);
     void start();
+    /**
+     * @brief startAtOnce 立即开始，不需要3s倒计时
+     */
+    void startAtOnce();
 
 signals:
     void finished();
