@@ -12,9 +12,11 @@
 DBusScreenshot::DBusScreenshot(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
     : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
 {
+    qCInfo(dsrApp) << "DBusScreenshot constructor called.";
 }
 
 DBusScreenshot::~DBusScreenshot()
 {
+    qCInfo(dsrApp) << "DBusScreenshot destructor called.";
 }
 
