@@ -43,6 +43,9 @@ class DBusScreenshotService: public QDBusAbstractAdaptor
                 "    </method>\n"
                 "    <method name=\"OcrScreenshot\"/>\n"
                 "    <method name=\"ScrollScreenshot\"/>\n"
+                "    <method name=\"CustomScreenshot\">\n"
+                "      <arg direction=\"in\" type=\"a{sv}\"/>\n"
+                "    </method>\n"
                 "    <method name=\"SavePathScreenshot\">\n"
                 "      <arg direction=\"in\" type=\"s\"/>\n"
                 "    </method>\n"
@@ -52,6 +55,9 @@ class DBusScreenshotService: public QDBusAbstractAdaptor
                 "    <signal name=\"Done\">\n"
                 "      <arg type=\"s\"/>\n"
                 "    </signal>\n"
+                "    <signal name=\"CustomDone\">\n"
+                "      <arg type=\"s\"/>\n"
+                "    </signal>\n"
                 "  </interface>\n"
                 "")
 public:
@@ -68,6 +74,7 @@ public:
 public: // PROPERTIES
 public Q_SLOTS: // METHODS
     void StartScreenshot();
+    void CustomScreenshot(const QVariantMap &params);
     void DelayScreenshot(qlonglong in0);
     void NoNotifyScreenshot();
     void OcrScreenshot();
@@ -80,6 +87,7 @@ public Q_SLOTS: // METHODS
 
 Q_SIGNALS: // SIGNALS
     void Done(const QString &in0);
+    void CustomDone(const QString &in0);
 private:
     bool m_singleInstance;
 };
