@@ -37,6 +37,7 @@
 #include "recordertablet.h"
 #include "dbusinterface/ocrinterface.h"
 #include "dbusinterface/pinscreenshotsinterface.h"
+#include "dbusinterface/aiassistantinterface.h"
 
 #include <DWindowManagerHelper>
 #include <DDialog>
@@ -397,6 +398,11 @@ public:
      * 确保不会功能问题
      */
     void initTreelandtAttributes();
+    
+    /**
+     * @brief 初始化音频和摄像头监视器（仅在录屏模式下使用）
+     */
+    void initAudioAndCameraWatchers();
 
     void setToolbarVisable(bool visable) { isHideToolBar =  visable;};
 
@@ -491,6 +497,7 @@ public slots:
     void saveScreenShot();
     void saveScreenShotToClipboardOnly();
     void saveScreenShotToFile();
+    void onAiAssistantSelected(int func);
     void prepareScreenshot();
     void hideScreenshotTips();
     void captureScreenshotImage();
@@ -1306,6 +1313,8 @@ private:
     int m_cursorBound;
     //ocr接口
     OcrInterface *m_ocrInterface = nullptr;
+    //AI助手接口
+    AiAssistantInterface *m_aiAssistantInterface = nullptr;
     /**
      * @brief 贴图接口
      */
