@@ -159,7 +159,7 @@ bool MainWindow::openImageAndName(const QImage &image, const QString &name, cons
 void MainWindow::onOpenOCR()
 {
     qCDebug(dsrApp) << "onOpenOCR called.";
-    saveImg();
+    saveToClipboard();
     qCDebug(dsrApp) << "Image saved before OCR.";
     // 测试
     if (m_ocrInterface == nullptr) {
@@ -177,7 +177,10 @@ void MainWindow::saveImg()
     m_saveInfo = m_toolBar->getSaveInfo(); // 获取保存信息
     qCDebug(dsrApp) << "Save info retrieved. Type:" << m_saveInfo.first << ", Format:" << m_saveInfo.second;
 
-    if (m_saveInfo.first == SubToolWidget::DESKTOP) {
+    QPair<int, int> live = Settings::instance()->getSaveOption();
+    int pathType = live.first;
+
+    if (pathType == SubToolWidget::DESKTOP) {
         qCDebug(dsrApp) << "保存到桌面";
         QString savePath = QStandardPaths::standardLocations(QStandardPaths::DesktopLocation).first();
         QString formatStr;
@@ -193,7 +196,7 @@ void MainWindow::saveImg()
         }
         m_lastImagePath = QString("%1/%2.%3").arg(savePath).arg(m_imageName).arg(formatStr);
         qCDebug(dsrApp) << "Image will be saved to:" << m_lastImagePath;
-    } else if (m_saveInfo.first == SubToolWidget::PICTURES) {
+    } else if (pathType == SubToolWidget::PICTURES) {
         qCDebug(dsrApp) << "保存到图片";
         QString savePath = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first() + QDir::separator() + "Screenshots";
         if ((!QDir(savePath).exists() && QDir().mkdir(savePath) == false) ||  // 文件不存在，且创建失败
@@ -214,7 +217,7 @@ void MainWindow::saveImg()
         }
         m_lastImagePath = QString("%1/%2.%3").arg(savePath).arg(m_imageName).arg(formatStr);
         qCDebug(dsrApp) << "Image will be saved to:" << m_lastImagePath;
-    } else if (m_saveInfo.first == SubToolWidget::ASK) {
+    } else if (pathType == SubToolWidget::ASK) {
         // 每次询问保存位置
         qCDebug(dsrApp) << "每次询问保存位置";
         m_toolBar->hide();
@@ -260,7 +263,7 @@ void MainWindow::saveImg()
         
         this->show();
         m_toolBar->show();
-    } else if (m_saveInfo.first == SubToolWidget::FOLDER) {
+    } else if (pathType == SubToolWidget::FOLDER) {
         // 使用指定位置保存
         QString savePath = Settings::instance()->getSavePath();
         qCDebug(dsrApp) << "保存到指定路径" << savePath;
@@ -268,7 +271,7 @@ void MainWindow::saveImg()
         // 如果指定路径不存在或无法访问，则切换到 FOLDER_CHANGE 模式
         if (savePath.isEmpty() || !QDir(savePath).exists() || !QFileInfo(savePath).isWritable()) {
             qCDebug(dsrApp) << "Specified path does not exist or is not writable, switching to folder change mode";
-            m_saveInfo.first = SubToolWidget::FOLDER_CHANGE;
+            pathType = SubToolWidget::FOLDER_CHANGE;
         } else {
             QString formatStr;
             if (m_saveInfo.second == static_cast<SubToolWidget::SAVEFORMAT>(SubToolWidget::PNG)) {
@@ -285,7 +288,7 @@ void MainWindow::saveImg()
         }
     }
     
-    if (m_saveInfo.first == SubToolWidget::FOLDER_CHANGE) {
+    if (pathType == SubToolWidget::FOLDER_CHANGE) {
         // 需要设置或更新指定位置
         qCDebug(dsrApp) << "设置或更新指定位置";
         m_toolBar->hide();
@@ -322,14 +325,21 @@ void MainWindow::saveImg()
         
         // 保存用户选择的路径作为指定路径
         QString selectedPath = QFileInfo(m_lastImagePath).dir().absolutePath();
+        qCWarning(dsrApp) << "FOLDER_CHANGE: Saving selected path:" << selectedPath;
         Settings::instance()->setSavePath(selectedPath);
         
         // 将 FOLDER_CHANGE 标记设置为 false，表示已经设置了指定路径
         Settings::instance()->setIsChangeSavePath(false);
+        qCWarning(dsrApp) << "FOLDER_CHANGE: Set isChangeSavePath to false";
         
         // 将保存选项更新为 FOLDER，表示下次直接使用指定路径
-        m_saveInfo.first = SubToolWidget::FOLDER;
-        Settings::instance()->setSaveOption(m_saveInfo);
+        pathType = SubToolWidget::FOLDER;
+        qCWarning(dsrApp) << "FOLDER_CHANGE: Updating save option from FOLDER_CHANGE to FOLDER";
+        {
+            QPair<int,int> newSave(pathType, m_saveInfo.second);
+            Settings::instance()->setSaveOption(newSave);
+            qCWarning(dsrApp) << "FOLDER_CHANGE: Save option updated, new config:" << newSave;
+        }
         
         // 处理文件扩展名
         QString fileSuffix = QFileInfo(m_lastImagePath).completeSuffix();
@@ -341,12 +351,21 @@ void MainWindow::saveImg()
         m_toolBar->show();
     }
     
-    //每次保存时重设isChangeSavePath
-    Settings::instance()->setIsChangeSavePath(false);
+    // 不在此处重置 isChangeSavePath，遵循实时配置
 
     bool isSaveState = true;
-    if (m_saveInfo.first != SubToolWidget::CLIPBOARD) {
+    if (pathType != SubToolWidget::CLIPBOARD) {
+        qCWarning(dsrApp) << "SAVE: Attempting to save image to:" << m_lastImagePath;
+        QDir saveDir = QFileInfo(m_lastImagePath).dir();
+        
         isSaveState = m_image.save(m_lastImagePath);
+        qCWarning(dsrApp) << "SAVE: Save result:" << isSaveState;
+        
+        if (isSaveState) {
+            qCWarning(dsrApp) << "SAVE SUCCESS: File saved successfully";
+        } else {
+            qCWarning(dsrApp) << "SAVE FAILED: Failed to save file";
+        }
     }
 
     // 发送通知
@@ -799,8 +818,9 @@ void MainWindow::sendNotify(QString savePath, bool bSaveState)
                                 QDBusConnection::sessionBus());
 
     if (!bSaveState) {
-        qCDebug(dsrApp) << __FUNCTION__;
+        qCWarning(dsrApp) << "SAVE FAILED: Save operation failed!";
         QString tips = QString(tr("Save failed. Please save it in your home directory."));
+        qCWarning(dsrApp) << "SAVE FAILED: Clearing save path";
         Settings::instance()->setSavePath("");
         QList<QVariant> arg;
         unsigned int id = 0;
