@@ -39,7 +39,7 @@ const QMap<QString, QMap<QString, QVariant>> ConfigSettings::m_defaultConfig = {
     // 截图保存选项，格式，保存位置选项
     //save_dir: 普通路径
     //save_dir_change: 指定路径是否需要改变
-    {"shot", {{"format", 0}, {"save_op", 0}, {"save_cursor", 0}, {"save_dir", ""},  {"save_dir_change", false}, {"border_index", 0}, {"save_ways", 0}, {"save_ask_dir", ""}}},
+    {"shot", {{"format", 0}, {"save_op", 0}, {"save_cursor", 0}, {"save_dir", ""},  {"save_dir_change", false}, {"border_index", 0}, {"save_ways", 0}, {"save_ask_dir", ""}, {"ai_assistant_used", false}}},
     // 录屏保存选项
     // curor 0 不录制鼠标，及不录制鼠标点击,1 录制鼠标,2 录制鼠标点击,3 录制鼠标，及录制鼠标点击,
     // audio 0 不录制任何音频,1 麦克风音频, 2 录制系统音频,3 录制混音,
