@@ -37,6 +37,7 @@ BigColorButton::BigColorButton(DWidget *parent)
 
 void BigColorButton::updateConfigColor(const QString &shape, const QString &key, int index)
 {
+    qCDebug(dsrApp) << "updateConfigColor called with shape:" << shape << ", key:" << key << ", index:" << index;
     if (shape == "common" && key == "color_index") {
         qCDebug(dsrApp) << "Updating color from config - shape:" << shape << "key:" << key << "index:" << index;
         setColor(colorIndexOf(index));
@@ -50,12 +51,14 @@ BigColorButton::~BigColorButton()
 
 void BigColorButton::paintEvent(QPaintEvent *)
 {
+    qCDebug(dsrApp) << "paintEvent entered";
     QPainter painter(this);
     painter.setRenderHints(QPainter::Antialiasing);
     painter.setPen(Qt::transparent);
 
     painter.setBrush(QBrush(QColor(0, 0, 0, 20)));
     if (m_isHover) {
+        qCDebug(dsrApp) << "Painting hover state";
         painter.drawRoundedRect(rect(), 4, 4);
     }
 
@@ -65,18 +68,21 @@ void BigColorButton::paintEvent(QPaintEvent *)
 
     qreal ration = this->devicePixelRatioF();
     if (m_isChecked) {
+        qCDebug(dsrApp) << "Painting checked state";
         QPixmap checkedPic = QIcon(":/images/action/colors_checked.svg"
                                   ).pixmap(BTN_SIZE);
         checkedPic.setDevicePixelRatio(ration);
 
         painter.drawPixmap(rect(), checkedPic);
     } else if (m_isHover && !m_isChecked) {
+        qCDebug(dsrApp) << "Painting hover and unchecked state";
         QPixmap hoverPic = QIcon(":/images/action/colors_hover.svg"
                                 ).pixmap(BTN_SIZE);
         hoverPic.setDevicePixelRatio(ration);
 
         painter.drawPixmap(rect(), hoverPic);
     } else {
+        qCDebug(dsrApp) << "Painting normal state";
         QPixmap normalPic = QIcon(":/images/action/colors_hover.svg"
                                  ).pixmap(BTN_SIZE);
         normalPic.setDevicePixelRatio(ration);
@@ -102,6 +108,7 @@ void BigColorButton::setColorIndex()
 */
 void BigColorButton::setCheckedStatus(bool checked)
 {
+    qCDebug(dsrApp) << "setCheckedStatus called with checked:" << checked;
     if (checked) {
         qCDebug(dsrApp) << "Setting checked status to:" << checked;
         m_isChecked = true;
@@ -111,7 +118,9 @@ void BigColorButton::setCheckedStatus(bool checked)
 
 void BigColorButton::enterEvent(QEvent *)
 {
+    qCDebug(dsrApp) << "enterEvent called";
     if (!m_isHover) {
+        qCDebug(dsrApp) << "Setting hover to true";
         m_isHover = true;
         update();
     }
@@ -119,7 +128,9 @@ void BigColorButton::enterEvent(QEvent *)
 
 void BigColorButton::leaveEvent(QEvent *)
 {
+    qCDebug(dsrApp) << "leaveEvent called";
     if (m_isHover) {
+        qCDebug(dsrApp) << "Setting hover to false";
         m_isHover = false;
         update();
     }
