@@ -5,12 +5,15 @@
 #include "subtoolwidget.h"
 #include "../camera_process.h"
 #include "../utils/configsettings.h"
+#include "../utils/saveutils.h"
 #include "../settings.h"
 #include "tooltips.h"
 #include "../utils.h"
 #include "../utils/log.h"
 #include "../accessibility/acTextDefine.h"
 #include "savemenumanager.h"
+#include "aiassistantwidget.h"
+#include "../utils/dbusutils.h"
 
 #include <QActionGroup>
 #include "../main_window.h"
@@ -44,6 +47,7 @@ DWIDGET_USE_NAMESPACE
 
 namespace {
 const QSize TOOL_ICON_SIZE = QSize(36, 36);
+const QSize SMALL_TOOL_ICON_SIZE = QSize(24, 24);
 const QSize TOOL_BUTTON_SIZE = QSize(36, 36);
 const QSize MEDIUM_TOOL_BUTTON_SIZE = QSize(56, 36);
 const QSize MIN_TOOL_BUTTON_SIZE = QSize(42, 40);
@@ -195,7 +199,7 @@ void SubToolWidget::initRecordOption()
     m_recordOptionMenu->installEventFilter(this);
     DFontSizeManager::instance()->bind(m_recordOptionMenu, DFontSizeManager::T6);
     // 保存格式
-    QAction *formatTitleAction = new QAction(tr("Format:"), m_recordOptionMenu);
+    QAction *formatTitleAction = new QAction(tr("Format"), m_recordOptionMenu);
     formatTitleAction->setFont(titleActionFont);
 
     QAction *gifAction = new QAction(tr("GIF"));
@@ -206,7 +210,7 @@ void SubToolWidget::initRecordOption()
         mp4Action->setText(tr("webm"));
     }
     // 帧数
-    QAction *fpsTitleAction = new QAction(tr("FPS:"), m_recordOptionMenu);
+    QAction *fpsTitleAction = new QAction(tr("FPS"), m_recordOptionMenu);
     fpsTitleAction->setFont(titleActionFont);
     QAction *fps5Action = new QAction(tr("5 fps"), m_recordOptionMenu);
     QAction *fps10Action = new QAction(tr("10 fps"), m_recordOptionMenu);
@@ -646,6 +650,25 @@ void SubToolWidget::initShotLabel()
     if (!(Utils::isTreelandMode))
          btnList.append(m_pinButton);
 
+    m_aiAssistantButton = new ToolButton();
+    m_aiAssistantButton->setIconSize(SMALL_TOOL_ICON_SIZE);
+    m_aiAssistantButton->setIcon(QIcon::fromTheme("ai_assistant"));
+    bool aiAssistantUsed = ConfigSettings::instance()->getValue("shot", "ai_assistant_used").toBool();
+    m_aiAssistantButton->setShowRedDot(!aiAssistantUsed);
+    Utils::setAccessibility(m_aiAssistantButton, AC_SUBTOOLWIDGET_AI_ASSISTANT_BUTTON);
+    m_shotBtnGroup->addButton(m_aiAssistantButton);
+    m_aiAssistantButton->setFixedSize(TOOL_BUTTON_SIZE);
+    installTipHint(m_aiAssistantButton, tr("AI Screenshot (A)"));
+    btnList.append(m_aiAssistantButton);
+    connect(m_aiAssistantButton, &ToolButton::clicked, this, [=] {
+        ConfigSettings::instance()->setValue("shot", "ai_assistant_used", true);
+        m_aiAssistantButton->setShowRedDot(false);
+        emit changeShotToolFunc("aiassistant");
+    });
+
+    if(!DBusUtils::isAiAssistantAvailable())
+        m_aiAssistantButton->hide();
+
     // 撤销按钮
     m_cancelButton = new ToolButton();
     m_cancelButton->setUndoButtonFlag(true);
@@ -696,13 +719,14 @@ void SubToolWidget::initShotLabel()
     m_saveLocalDirButton = new SaveButton();
     m_saveLocalDirButton->setCheckable(false);
     updateSaveButtonTip();
-    m_saveLocalDirButton->installEventFilter(this);
     // m_saveLocalDirButton->setIcon(QIcon::fromTheme("save"));
     Utils::setAccessibility(m_saveLocalDirButton, AC_SUBTOOLWIDGET_SAVETOLOCAL_BUTTON);
     
     // 创建并设置保存菜单管理器
     SaveMenuManager *saveMenuManager = new SaveMenuManager(this);
     m_saveLocalDirButton->setOptionsMenu(saveMenuManager->getMenu());
+    // 连接保存选项改变信号，更新tooltip
+    connect(saveMenuManager, &SaveMenuManager::saveOptionChanged, this, &SubToolWidget::updateSaveButtonTip);
     
     m_shotBtnGroup->addButton(m_saveLocalDirButton);
     // m_saveLocalDirButton->setFixedSize(TOOL_BUTTON_SIZE);
@@ -714,6 +738,7 @@ void SubToolWidget::initShotLabel()
         m_scrollShotButton->hide(); //隐藏滚动截图按钮
         m_ocrButton->hide(); //隐藏ocr按钮
         m_pinButton->hide(); //隐藏pin按钮
+        m_aiAssistantButton->hide(); //隐藏AI助手按钮
     }
 
     m_saveSeperatorBeg = new DVerticalLine(this);
@@ -798,66 +823,88 @@ void SubToolWidget::initShotLabel()
     qCDebug(dsrApp) << "截图工具栏UI已初始化";
 }
 
+void SubToolWidget::showAIAssistantWidget()
+{
+    // 兼容旧接口：转发到菜单弹出逻辑
+    if (m_aiAssistantButton) {
+        QMetaObject::invokeMethod(m_aiAssistantButton, "click", Qt::QueuedConnection);
+    }
+}
+
+
 // 更新保存按钮的提示信息
 void SubToolWidget::updateSaveButtonTip()
 {
-    // SaveWays t_saveWays = ConfigSettings::instance()->getValue("shot", "save_ways").value<SaveWays>();
-    //  QString tipText;
-    // if (t_saveWays == Ask) {
-    //     tipText = tr("Save to local");
-    // } else if (t_saveWays == SpecifyLocation) {
-    //     // 获取当前保存设置
-    //     SaveAction saveAction = ConfigSettings::instance()->getValue("shot", "save_op").value<SaveAction>();
+    qCWarning(dsrApp) << "========== updateSaveButtonTip 开始 ==========";
+    
+    if (!m_saveLocalDirButton) {
+        qCWarning(dsrApp) << "updateSaveButtonTip: m_saveLocalDirButton 为空，直接返回";
+        return;
+    }
+    
+    // 参考saveAction函数的读取方式
+    SaveWays saveWays = ConfigSettings::instance()->getValue("shot", "save_ways").value<SaveWays>();
+    SaveAction saveOp = ConfigSettings::instance()->getValue("shot", "save_op").value<SaveAction>();
+    bool isChangeOnSave = ConfigSettings::instance()->getValue("shot", "save_dir_change").toBool();
+    QString savedPath = ConfigSettings::instance()->getValue("shot", "save_dir").toString();
+    const bool hasHistoryPath = !savedPath.isEmpty() && QFileInfo::exists(savedPath);
 
-    //     switch (saveAction) {
-    //     case SaveToDesktop: {
-    //         tipText = tr("Save to Desktop");
-    //         break;
-    //     }
-    //     case SaveToImage: {
-    //         tipText = tr("Save to Pictures");
-    //         break;
-    //     }
-    //     case SaveToSpecificDir: {
-    //         bool changeIsChecked = m_changeSaveToSpecialPath && ((m_changeSaveToSpecialPath &&m_changeSaveToSpecialPath->isChecked()) || (m_scrollChangeSaveToSpecialPath && m_scrollChangeSaveToSpecialPath->isChecked()));
-    //         qWarning() << "changeIsChecked:"<<changeIsChecked;
-    //         QString specificPath = ConfigSettings::instance()->getValue("shot", "save_dir").toString();
-    //         bool specialPathExits = !specificPath.isEmpty() && QFileInfo::exists(specificPath);
-    //         qWarning() << "specialPathExits:"<<specialPathExits;
-    //         // 保存时更新
-    //         bool tipsUpdateSaved = specialPathExits && changeIsChecked;
-    //         qWarning() << "tipsUpdateSaved:"<<tipsUpdateSaved;
-    //         // 保存时设置(选中且目录为空不为空)
-    //         bool tipsSetSaved = changeIsChecked;
-    //         qWarning() << "tipsSetSaved:"<<tipsSetSaved;
-    //         // 保存到目录 (目录不为空且存在)
-    //         bool tipsSpecialSaved = m_saveToSpecialPathAction && m_saveToSpecialPathAction->isChecked() && specialPathExits;
-    //          qWarning() << "tipsSpecialSaved:"<<tipsSpecialSaved;
+    qCWarning(dsrApp) << "updateSaveButtonTip: saveWays=" << static_cast<int>(saveWays) 
+                      << "saveOp=" << static_cast<int>(saveOp)
+                      << "isChangeOnSave=" << isChangeOnSave
+                      << "savedPath=" << savedPath
+                      << "hasHistoryPath=" << hasHistoryPath;
 
-    //         if (tipsUpdateSaved) {
-    //             tipText = tr("Change the path on save");
-    //             qWarning() << "tipsUpdateSaved";
-
-    //         }
-    //         else if(tipsSetSaved) {
-    //             tipText = tr("Set a path on save");
-    //             qWarning() << "tipsSetSaved";
-    //         } else if(tipsSpecialSaved) {
-    //             tipText = tr("Save to %1").arg(specificPath);
-    //             qWarning() << "tipsSpecialSaved";
-    //         } else {
-    //              tipText = tr("Save to local");
-    //             qWarning() << "not set saved";
-    //         }
-    //         qWarning() << tipText;
-    //         break;
-    //     }
-    //     default:
-    //         tipText = tr("Save to local");
-    //         break;
-    //     }
-    // }
-    // installTipHint(m_saveLocalDirButton, tipText);
+    QString tipText;
+    if (saveWays == Ask) { 
+        // 每次询问模式
+        tipText = tr("Save to local");
+        qCWarning(dsrApp) << "updateSaveButtonTip: 进入每次询问模式，tipText=" << tipText;
+    } else if (saveWays == SpecifyLocation) {
+        // 指定位置模式，根据save_op显示具体保存位置
+        qCWarning(dsrApp) << "updateSaveButtonTip: 进入指定位置模式，saveOp=" << static_cast<int>(saveOp);
+        switch (saveOp) {
+            case SaveToDesktop:
+                tipText = tr("Save to Desktop");
+                qCWarning(dsrApp) << "updateSaveButtonTip: SaveToDesktop分支，tipText=" << tipText;
+                break;
+            case SaveToImage:
+                tipText = tr("Save to Pictures");
+                qCWarning(dsrApp) << "updateSaveButtonTip: SaveToImage分支，tipText=" << tipText;
+                break;
+            case SaveToSpecificDir:
+                qCWarning(dsrApp) << "updateSaveButtonTip: SaveToSpecificDir分支，isChangeOnSave=" << isChangeOnSave;
+                if (isChangeOnSave) {
+                    // 保存时选择/更新位置
+                    tipText = hasHistoryPath ? tr("Update the location when saving")
+                                             : tr("Select a location when saving");
+                    qCWarning(dsrApp) << "updateSaveButtonTip: isChangeOnSave=true，hasHistoryPath=" << hasHistoryPath 
+                                      << "tipText=" << tipText;
+                } else {
+                    // 保存到指定路径
+                    tipText = hasHistoryPath ? tr("Save to %1").arg(savedPath)
+                                             : tr("Save to local");
+                    qCWarning(dsrApp) << "updateSaveButtonTip: isChangeOnSave=false，hasHistoryPath=" << hasHistoryPath 
+                                      << "tipText=" << tipText;
+                }
+                break;
+            default:
+                // 其他情况（SaveToClipboard, AutoSave, CustomScreenSave等）
+                tipText = tr("Save to local");
+                qCWarning(dsrApp) << "updateSaveButtonTip: default分支，saveOp=" << static_cast<int>(saveOp) 
+                                  << "tipText=" << tipText;
+                break;
+        }
+    } else {
+        // 其他情况，保持原来的方式
+        tipText = tr("Save to local");
+        qCWarning(dsrApp) << "updateSaveButtonTip: 其他情况分支，saveWays=" << static_cast<int>(saveWays) 
+                          << "tipText=" << tipText;
+    }
+    
+    qCWarning(dsrApp) << "updateSaveButtonTip: 最终tipText=" << tipText;
+    installTipHint(m_saveLocalDirButton, tipText);
+    qCWarning(dsrApp) << "========== updateSaveButtonTip 结束 ==========";
 }
 
 void SubToolWidget::initShotOption()
@@ -1379,6 +1426,20 @@ void SubToolWidget::initScrollLabel()
     m_scrollSubTool = new DLabel(this);
     QList<ToolButton *> btnList;
 
+    // AI 助手（滚动截图工具栏首位）
+    m_aiAssistantScrollButton = new ToolButton();
+    m_aiAssistantScrollButton->setIconSize(SMALL_TOOL_ICON_SIZE);
+    m_aiAssistantScrollButton->setIcon(QIcon::fromTheme("ai_assistant"));
+    Utils::setAccessibility(m_aiAssistantScrollButton, AC_SUBTOOLWIDGET_AI_ASSISTANT_BUTTON);
+    m_aiAssistantScrollButton->setFixedSize(TOOL_BUTTON_SIZE);
+    installTipHint(m_aiAssistantScrollButton, tr("AI Screenshot (A)"));
+    btnList.append(m_aiAssistantScrollButton);
+    connect(m_aiAssistantScrollButton, &ToolButton::clicked, this, [=]{
+        emit changeShotToolFunc("aiassistant");
+    });
+    if (!DBusUtils::isAiAssistantAvailable())
+        m_aiAssistantScrollButton->hide();
+
     //文字识别按钮
     m_ocrScrollButton = new ToolButton();
     Utils::setAccessibility(m_ocrScrollButton, AC_SUBTOOLWIDGET_KEYBOARD_BUTTON);
@@ -1413,6 +1474,8 @@ void SubToolWidget::initScrollLabel()
     // 创建并设置保存菜单管理器
     SaveMenuManager *scrollSaveMenuManager = new SaveMenuManager(this);
     m_saveLocalDirButton->setOptionsMenu(scrollSaveMenuManager->getMenu());
+    // 连接保存选项改变信号，更新tooltip
+    connect(scrollSaveMenuManager, &SaveMenuManager::saveOptionChanged, this, &SubToolWidget::updateSaveButtonTip);
     
     m_shotBtnGroup->addButton(m_saveLocalDirButton);
     // m_saveLocalDirButton->setFixedSize(TOOL_BUTTON_SIZE);
@@ -1827,6 +1890,13 @@ int SubToolWidget::getFuncSubToolX(QString &shape)
             x = m_penButton->x();
         } else if (shape == "text") {
             x = m_textButton->x();
+        } else if (shape == "aiassistant") {
+            // 根据当前模式选择对应的 AI 按钮（普通/滚动）
+            if (currentWidget() == m_scrollSubTool && m_aiAssistantScrollButton) {
+                x = m_aiAssistantScrollButton->x();
+            } else {
+                x = m_aiAssistantButton ? m_aiAssistantButton->x() : -1;
+            }
         }  else  {
             x = -1;
         }
@@ -1835,37 +1905,32 @@ int SubToolWidget::getFuncSubToolX(QString &shape)
     return x;
 }
 
+
+QRect SubToolWidget::getAiButtonGlobalRect() const
+{
+    const ToolButton *btn = nullptr;
+    if (currentWidget() == m_scrollSubTool && m_aiAssistantScrollButton) {
+        btn = m_aiAssistantScrollButton;
+    } else if (m_aiAssistantButton) {
+        btn = m_aiAssistantButton;
+    }
+    if (!btn) return QRect();
+    QPoint topLeft = btn->mapToGlobal(QPoint(0, 0));
+    QRect rect(topLeft, btn->size());
+    return rect;
+}
+
+QPoint SubToolWidget::getAiButtonGlobalCenter() const
+{
+    QRect r = getAiButtonGlobalRect();
+    QPoint center = r.center();
+    return center;
+}
+
 // 屏蔽DMenu，触发QAction Trigger时，收回菜单
 bool SubToolWidget::eventFilter(QObject *watched, QEvent *event)
 {
-    // 为保存按钮提供动态 ToolTip 文案
-    if (watched == m_saveLocalDirButton) {
-        if (event->type() == QEvent::ToolTip) {
-            int saveWays = ConfigSettings::instance()->getValue("shot", "save_ways").toInt(); // 0: Ask, 1: Specify
-            bool isChangeOnSave = ConfigSettings::instance()->getValue("shot", "save_dir_change").toBool();
-            QString savedPath = ConfigSettings::instance()->getValue("shot", "save_dir").toString();
-            const bool hasHistoryPath = !savedPath.isEmpty() && QFileInfo::exists(savedPath);
 
-            QString tipText;
-            if (saveWays == 0) { 
-                tipText = tr("Save to local");
-            } else {
-                if (isChangeOnSave) {
-                    tipText = hasHistoryPath ? tr("Update the location when saving")
-                                             : tr("Select a location when saving");
-                } else {
-                    // 菜单选中具体的自定义路径 → 显示"保存到[路径]"
-                    tipText = hasHistoryPath ? tr("Save to %1").arg(savedPath)
-                                             : tr("Save to local");
-                }
-            }
-
-            if (m_saveLocalDirButton)
-                installTipHint(m_saveLocalDirButton, tipText);
-
-            return true;
-        }
-    }
 
     if (watched == m_recordOptionMenu || watched == m_optionMenu || watched == m_scrollOptionMenu || watched == m_saveToSpecialPathMenu || watched == m_scrollSaveToSpecialPathMenu) {
         if (event->type() == QEvent::MouseButtonPress) {
@@ -1963,7 +2028,7 @@ void SubToolWidget::setVideoButtonInitFromSub()
 
 void SubToolWidget::shapeClickedFromWidget(QString shape)
 {
-    qCDebug(dsrApp) << "SubToolWidget::shapeClickedFromWidget called with shape:" << shape;
+    qCWarning(dsrApp) << "SubToolWidget::shapeClickedFromWidget called with shape:" << shape;
 
     if (!shape.isEmpty()) {
         if (shape == "pinScreenshots") {
@@ -2006,7 +2071,13 @@ void SubToolWidget::shapeClickedFromWidget(QString shape)
                     m_scrollOptionMenu->hide();
                 }
             }
-
+        } else if (shape == "aiassistant") {
+            qCWarning(dsrApp) << "AI assistant mode: showing AI assistant tool.";
+            if (m_aiAssistantButton) {
+                m_aiAssistantButton->click();
+            } else {
+                emit changeShotToolFunc("aiassistant");
+            }
         } else if (shape == "keyBoard") {
             m_keyBoardButton->click();
         } else if (shape == "camera") {
