@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ar">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>شرح</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>ترجمة</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>اسأل AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>ملخص</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>تغيير المسار عند الحفظ</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>سطح المكتب</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>الصور</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>سطح المكتب</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>الصور</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,7 +557,7 @@ Press and hold Shift to draw a straight line</source>
         <translation>اعدادات</translation>
     </message>
     <message>
-        <source>Format:</source>
+        <source>Format</source>
         <translation>النوع</translation>
     </message>
     <message>
@@ -542,8 +577,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>كاميرا الويب</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>إطار في الثانية FPS:</translation>
+        <source>FPS</source>
+        <translation>إطار في الثانية FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Change the path on save</source>
         <translation>تغيير المسار عند الحفظ</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>النوع</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -708,11 +739,23 @@ Hold down Shift to draw squares or circles.</source>
     </message>
     <message>
         <source>Update the location when saving</source>
-        <translation type="unfinished"></translation>
+        <translation>تحديث الموقع عند الحفظ</translation>
     </message>
     <message>
         <source>Select a location when saving</source>
-        <translation type="unfinished"></translation>
+        <translation>اختر موقع عند الحفظ</translation>
+    </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>ملخص (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>حفظ إلى سطح المكتب</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>حفظ إلى الصور</translation>
     </message>
 </context>
 <context>
