@@ -110,7 +110,7 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"/>
+        <translation>deepin-screen-recorder</translation>
     </message>
     <message>
         <source>Open Folder</source>
@@ -118,7 +118,7 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
     </message>
     <message>
         <source>Screenshot finished and copy to clipboard</source>
-        <translation type="unfinished"/>
+        <translation>Ekran görüntüsü tamamlandı və klippordaya kopyaladı</translation>
     </message>
 </context>
 <context>
@@ -727,4 +727,4 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Yeni ekran qeydi</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
