@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="bo">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>སྤྱིར་བཤུས་བྱེད་པ།</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>སྒྲིག་བཀོད་བྱ་རྒྱུ།</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>སྒྲིག་བཀོད་བྱ་རྒྱུ།</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>སྒྲིག་བཀོད་བྱ་རྒྱུ།</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>ཉར་སྐབས་གནས་ས་གསར་སྒྱུར་བྱེད་པ།</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>ཅོག་ངོས།</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>དབྱིབས།</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>ཅོག་ངོས།</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>དབྱིབས།</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,7 +557,7 @@ Shiftམནན་ནས་དྲང་ཐིག་འབྲི་ཐུབ།</t
         <translation>སྒྲིག་བཀོད་(F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
+        <source>Format</source>
         <translation>རྣམ་བཞག</translation>
     </message>
     <message>
@@ -542,7 +577,7 @@ Shiftམནན་ནས་དྲང་ཐིག་འབྲི་ཐུབ།</t
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
+        <source>FPS</source>
         <translation>ལྡེབ་གྲངས།</translation>
     </message>
     <message>
@@ -649,10 +684,6 @@ Shiftམནན་ནས་ཐད་དཔྱང་དང་ཆུ་སྙོམ
         <source>Change the path on save</source>
         <translation>ཉར་སྐབས་གནས་ས་གསར་སྒྱུར་བྱེད་པ།</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>རྣམ་བཞག་ </translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་
         <source>Select a location when saving</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>སྒྲིག་བཀོད་བྱ་རྒྱུ་ (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>ཅོག་ངོས་དུ་ཉར་བ།</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>བཤུས་འགོད་དུ་ཉར་བ།</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
