@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="br">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Dizober</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Kemmoù</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Kemer an AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Kemmoù</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Change the path on save</source>
         <translation>تغيير المسار عند الحفظ</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Burev</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Skeudennioù</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Update the location when saving</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Burev</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Skeudennioù</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>الإعدادات (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Stumm:</translation>
+        <source>Format</source>
+        <translation>Stumm</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Change the path on save</source>
         <translation>تغيير المسار عند الحفظ</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Stumm</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -714,6 +745,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation></translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Tapadenn AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Enrollañ e-barzh ar burev</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Enrollañ e-barzh ar skeudenn</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
