@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ca">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Explica</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Traduï</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Pregunta a l&apos;IA</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Resum</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <source>Change the path on save</source>
         <translation>Canvia el camí per desar</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Escriptori</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Imatges</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <source>Update the location when saving</source>
         <translation>Actualitza la ubicació quan es desa</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Escriptori</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Imatges</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Manteniu premuda la tecla Maj per dibuixar una línia recta.</translation>
         <translation>Configuració (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Manteniu premuda la tecla Maj per dibuixar una línia recta.</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Manteniu premuda la tecla Maj per dibuixar una fletxa vertical o horitzontal.</t
         <source>Change the path on save</source>
         <translation>Canvia el camí per desar</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -714,6 +745,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation>Selecciona una ubicació quan es desa</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Resum (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Desa a l&apos;escriptori</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Desa a les imatges</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
