@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="cs">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Vysvětlit</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Přeložit</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Zeptejte se AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Shrnutí</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <source>Change the path on save</source>
         <translation>Změnit popis umístění pro ukládání</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Plocha</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Obrázky</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <source>Update the location when saving</source>
         <translation>Aktualizovat umístění při ukládání</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Plocha</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Obrázky</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Stiskněte a podržte klávesu Shift pro kreslení přímky</translation>
         <translation>Nastavení (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Formát:</translation>
+        <source>Format</source>
+        <translation>Formát</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Stiskněte a podržte klávesu Shift pro kreslení přímky</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>SN/S:</translation>
+        <source>FPS</source>
+        <translation>SN/S</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipk
         <source>Change the path on save</source>
         <translation>Změnit popis umístění pro ukládání</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Formát</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -714,6 +745,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation>Vybrat umístění při ukládání</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Snímek AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Uložit na plochu</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Uložit do obrázků</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
