@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="da">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Forklare</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Oversæt</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Spørg AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Resumé</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -142,7 +161,7 @@ eller tryk på genvejen igen, for at stoppe optagelse</translation>
     </message>
     <message>
         <source>Specified Location</source>
-        <translation type="unfinished">Angivet sted</translation>
+        <translation>Angivet sted</translation>
     </message>
     <message>
         <source>Set a path on save</source>
@@ -152,6 +171,14 @@ eller tryk på genvejen igen, for at stoppe optagelse</translation>
         <source>Change the path on save</source>
         <translation type="unfinished">Ændr stien ved opbevaring</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Skrivebord</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Billeder</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ eller tryk på genvejen igen, for at stoppe optagelse</translation>
         <source>Update the location when saving</source>
         <translation>Opdateret sted ved opbevaring</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Skrivebord</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Billeder</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Hold Shift nede for at tegne en ret linje</translation>
         <translation>Indstillinger (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Hold Shift nede for at tegne en ret linje</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Tryk og hold Shift for at tegne en vertikal eller horisontal pil</translation>
         <source>Change the path on save</source>
         <translation>Ændr stien ved opbevaring</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Hold Shift nede for at tegne kvadrater eller cirkler.</translation>
         <source>Select a location when saving</source>
         <translation>Vælg et sted ved opbevaring</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI Skærmbillede (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Gem til Skrivebord</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Gem til billeder</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
