@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="de">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Erklären</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Übersetzen</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>AI fragen</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Zusammenfassung</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <source>Change the path on save</source>
         <translation>Beim Speichern den Pfad ändern</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Schreibtisch</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Bilder</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <source>Update the location when saving</source>
         <translation>Beim Speichern den Pfad ändern</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Schreibtisch</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Bilder</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Umschalttaste gedrückt halten, um eine gerade Linie zu zeichnen</translation>
         <translation>Einstellungen (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Umschalttaste gedrückt halten, um eine gerade Linie zu zeichnen</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>BpS:</translation>
+        <source>FPS</source>
+        <translation>BpS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Umschalttaste gedrückt halten, um einen vertikalen oder horizontalen Pfeil zu z
         <source>Change the path on save</source>
         <translation>Beim Speichern den Pfad ändern</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Halten Sie die Umschalttaste gedrückt, um Quadrate oder Kreise zu zeichnen.</tr
         <source>Select a location when saving</source>
         <translation>Beim Speichern einen Pfad festlegen</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI-Bildschirmfoto (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Auf den Schreibtisch speichern</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Auf Bilder speichern</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
