@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="en">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Explain</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Translate</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Ask AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Summary</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</translation>
         <source>Change the path on save</source>
         <translation>Change the path on save</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Desktop</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Pictures</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</translation>
         <source>Update the location when saving</source>
         <translation>Update the location when saving</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Desktop</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Pictures</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -557,10 +592,6 @@ Press and hold Shift to draw a straight line</translation>
         <source>Settings (F3)</source>
         <translation>Settings (F3)</translation>
     </message>
-    <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
-    </message>
     <message>
         <source>GIF</source>
         <translation>GIF</translation>
@@ -578,8 +609,8 @@ Press and hold Shift to draw a straight line</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -715,6 +746,18 @@ Hold down Shift to draw squares or circles.</translation>
         <source>Select a location when saving</source>
         <translation>Select a location when saving</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI Screenshot (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Save to Desktop</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Save to Pictures</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
