@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="fi">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Selitä</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Käännä</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Kysy AI:lle</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Yhteenveto</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Change the path on save</source>
         <translation>Muuta polkua tallentaessa</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Työpöytä</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Kuvia</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Update the location when saving</source>
         <translation>Päivitä sijainti tallentaessa</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Työpöytä</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Kuvia</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Vedä suora viiva pitämällä Shift-painettuna</translation>
         <translation>Asetukset (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Muoto:</translation>
+        <source>Format</source>
+        <translation>Muoto</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Vedä suora viiva pitämällä Shift-painettuna</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
         <source>Change the path on save</source>
         <translation>Muuta polkua tallentaessa</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Muoto</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Pidä Shift-näppäintä painettuna piirtääksesi neliöitä tai ympyröitä.</
         <source>Select a location when saving</source>
         <translation>Valitse sijainti tallentaessa</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI-näyttökuva (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Tallenna työpöydälle</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Tallenna kuvakuvioihin</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
