@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="fr">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Expliquer</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Traduire</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Demander à AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Résumé</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ ou appuyer à nouveau sur le raccourci pour arrêter l&apos;enregistrement</tran
         <source>Change the path on save</source>
         <translation>Changer le chemin d&apos;enregistrement</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Bureau</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Images</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ ou appuyer à nouveau sur le raccourci pour arrêter l&apos;enregistrement</tran
         <source>Update the location when saving</source>
         <translation>Mettre à jour l&apos;emplacement lors de l&apos;enregistrement</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Bureau</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Images</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Maintenir la touche Maj enfoncée pour dessiner une ligne</translation>
         <translation>Paramètres (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format :</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -541,10 +576,6 @@ Maintenir la touche Maj enfoncée pour dessiner une ligne</translation>
         <source>webm</source>
         <translation>webm</translation>
     </message>
-    <message>
-        <source>FPS:</source>
-        <translation>FPS :</translation>
-    </message>
     <message>
         <source>5 fps</source>
         <translation>5 fps</translation>
@@ -649,10 +680,6 @@ Maintenir la touche Maj enfoncée pour dessiner une flèche verticale ou horizon
         <source>Change the path on save</source>
         <translation>Changer le chemin d&apos;enregistrement</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +742,22 @@ Maintenir la touche Maj enfoncée pour dessiner des carrés ou des cercles.</tra
         <source>Select a location when saving</source>
         <translation>Sélectionner un emplacement lors de l&apos;enregistrement</translation>
     </message>
+    <message>
+        <source>FPS</source>
+        <translation>FPS</translation>
+    </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Capture d&apos;écran AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Enregistrer sur le bureau</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Enregistrer dans les images</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
