@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="gl_ES">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Explicar</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Traducir</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Preguntar a AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Resumen</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <source>Change the path on save</source>
         <translation>Cambia o camiño ao gardar</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Escritorio</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Imaxes</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <source>Update the location when saving</source>
         <translation>Actualiza a localización ao gardar</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Escritorio</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Imaxes</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Manteña premida a tecla Maiúsculas para debuxar unha liña recta</translation>
         <translation>Configuración (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Formato:</translation>
+        <source>Format</source>
+        <translation>Formato</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Manteña premida a tecla Maiúsculas para debuxar unha liña recta</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizo
         <source>Change the path on save</source>
         <translation>Cambia o camiño ao gardar</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Formato</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Mantén premida a tecla Maiús para debuxar cadrados ou círculos.</translation>
         <source>Select a location when saving</source>
         <translation>Selecciona unha localización ao gardar</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Captura de pantalla AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Gardar no escritorio</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Gardar en imaxes</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
