@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="hu">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Magyarázat</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Fordítás</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Kérdezzen AI-t</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Összefoglaló</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</transla
         <source>Change the path on save</source>
         <translation>Mentéskor módosítsa az elérési utat</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Asztal</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Képek</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</transla
         <source>Update the location when saving</source>
         <translation>Mentéskor módosítsa az elérési utat</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Asztal</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Képek</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Egyenes vonal rajzolásához tartsa lenyomva a Shift billentyűt</translation>
         <translation>Beállítások (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Formátum:</translation>
+        <source>Format</source>
+        <translation>Formátum</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Egyenes vonal rajzolásához tartsa lenyomva a Shift billentyűt</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Függőleges vagy vízszintes nyíl rajzolásához tartsa lenyomva a Shift bille
         <source>Change the path on save</source>
         <translation>Mentéskor módosítsa az elérési utat</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Formátum</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Tartsa lenyomva a Shift billentyűt négyzetek vagy körök rajzolásához.</tra
         <source>Select a location when saving</source>
         <translation>Állítson be egy elérési utat a mentéshez</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI képernyőkép (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Mentés a Asztalra</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Mentés a Képekbe</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
