@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="it">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Spiega</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Traduci</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Chiedi a AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Riassunto</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <source>Change the path on save</source>
         <translation>Cambia il percorso di salvataggio</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Desktop</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Immagini</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <source>Update the location when saving</source>
         <translation>Aggiorna la posizione di salvataggio</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Desktop</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Immagini</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Tieni premuto Maiusc per tracciare una linea retta</translation>
         <translation>Impostazioni (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Formato:</translation>
+        <source>Format</source>
+        <translation>Formato</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Tieni premuto Maiusc per tracciare una linea retta</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Tieni premuto Maiusc per disegnare una freccia verticale o orizzontale</translat
         <source>Change the path on save</source>
         <translation>Cambia il percorso di salvataggio</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Formato</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Tieni premuto Maiusc per disegnare quadrati o cerchi.</translation>
         <source>Select a location when saving</source>
         <translation>Seleziona una posizione di salvataggio</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Screenshot AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Salva sul desktop</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Salva nelle immagini</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
