@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ko">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>설명</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>번역</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>AI 물어보기</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>요약</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>저장 시 경로 변경</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>바탕화면</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>이미지</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation>저장 시 위치 업데이트</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>바탕화면</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>이미지</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -525,8 +560,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>설정 (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>형식:</translation>
+        <source>Format</source>
+        <translation>형식</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -545,8 +580,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -653,10 +688,6 @@ Shift를 누르고 놓아 수직 또는 수평 화살표를 그립니다</transl
         <source>Change the path on save</source>
         <translation>저장 시 경로 변경</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>형식</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -719,6 +750,18 @@ Shift 키를 누른 채로 정사각형이나 원을 그립니다.</translation>
         <source>Select a location when saving</source>
         <translation>저장 시 위치 선택</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI 스크린샷 (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>바탕화면에 저장</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>사진에 저장</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
