@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="lo">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>ອຘິບັດ</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>ການການສະກຽງ</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>ຖາມ AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>ສະຖານທີ່ທີ່ກຳນົດ</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>ປ່ຽນທິດທາງເມື່ອບັນທຶກ</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>ພາບຫນ້າທີ່ສະແດງ</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>ພາບ</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation>ປັບແຕ່ງສະຖານທີ່ເມື່ອບັນທຶກ</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>ພາບຫນ້າທີ່ສະແດງ</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>ພາບ</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -554,10 +589,6 @@ Press and hold Shift to draw a straight line</source>
         <source>Settings (F3)</source>
         <translation>ການຕັ້ງຄ່າ (F3)</translation>
     </message>
-    <message>
-        <source>Format:</source>
-        <translation>ຮູບແບບ:</translation>
-    </message>
     <message>
         <source>GIF</source>
         <translation>GIF</translation>
@@ -575,8 +606,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -712,6 +743,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation>ເລືອກສະຖານທີ່ເມື່ອບັນທຶກ</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>ສະກີນສໍາເນົາ AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>ບັນທຶກໃສ່ພາບຫນ້າທີ່ສະແດງ</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>ບັນທຶກໃສ່ຮູບແບບ</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
