@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ms">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Terangkan</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Terjemahkan</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Tanya AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Ringkasan</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <source>Change the path on save</source>
         <translation>Ubah laluan ketika simpan</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Atas Meja</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Gambar</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <source>Update the location when saving</source>
         <translation>Ubah laluan ketika simpan</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Atas Meja</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Gambar</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Tekan dan tahan kekunci Shift untuk membentuk satu garisan lurus</translation>
         <translation>Tetapan (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Tekan dan tahan kekunci Shift untuk membentuk satu garisan lurus</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Tekan dan tahan kekunci Shift untuk melukis anak panah menegak atau mengufuk</tr
         <source>Change the path on save</source>
         <translation>Ubah laluan ketika simpan</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Tahan Shift untuk melukis segi empat sama atau bulatan.</translation>
         <source>Select a location when saving</source>
         <translation>Tetapkan laluan ketika simpan</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Tangkap Layar AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Simpan ke Atas Meja</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Simpan ke Gambar</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
