@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="nl">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Uitleggen</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Vertalen</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Vraag AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Samenvatting</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Change the path on save</source>
         <translation>Locatie wijzigen na klikken op opslaan</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Bureaublad</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Afbeeldingen</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Update the location when saving</source>
         <translation>Locatie wijzigen na klikken op opslaan</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Bureaublad</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Afbeeldingen</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Houd Shift ingedrukt om een rechte lijn te trekken</translation>
         <translation>Instellingen (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Formaat:</translation>
+        <source>Format</source>
+        <translation>Formaat</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Houd Shift ingedrukt om een rechte lijn te trekken</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Houd Shift ingedrukt om een verticale of horizontale pijl te tekenen</translatio
         <source>Change the path on save</source>
         <translation>Locatie wijzigen na klikken op opslaan</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Formaat:</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Houd Shift ingedrukt om vierkanten of cirkels te tekenen.</translation>
         <source>Select a location when saving</source>
         <translation>Locatie kiezen na klikken op opslaan</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI Schermopname (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Opslaan na bureaublad</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Opslaan na afbeeldingen</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
