@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="pl">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Wyjaśnij</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Przetłumacz</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Zapytaj AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Podsumowanie</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <source>Change the path on save</source>
         <translation>Zmień ścieżkę zapisu</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Pulpit</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Obrazy</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <source>Update the location when saving</source>
         <translation>Zmień ścieżkę zapisu</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Pulpit</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Obrazy</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Przytrzymaj Shift, aby rysować prostą linię</translation>
         <translation>Ustawienia (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Przytrzymaj Shift, aby rysować prostą linię</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Przytrzymaj Shift, aby rysować pionową lub poziomą strzałkę</translation>
         <source>Change the path on save</source>
         <translation>Zmień ścieżkę zapisu</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Przytrzymaj Shift, aby narysować kwadraty lub koła.</translation>
         <source>Select a location when saving</source>
         <translation>Ustaw ścieżkę zapisu</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Zrzut ekranu AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Zapisz na pulpicie</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Zapisz na zdjęcia</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
