@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="pt">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Explica</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Traduzir</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Perguntar AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Resumo</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Change the path on save</source>
         <translation>Alterar o caminho para salvar</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Ambiente de trabalho</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Imagens</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Update the location when saving</source>
         <translation>Atualizar a localização ao guardar</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Ambiente de trabalho</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Imagens</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Pressionar e manter Shift para desenhar uma linha reta</translation>
         <translation>Definições (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Formato:</translation>
+        <source>Format</source>
+        <translation>Formato</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Pressionar e manter Shift para desenhar uma linha reta</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Pressionar e manter Shift para desenhar uma seta vertical ou horizontal</transla
         <source>Change the path on save</source>
         <translation>Alterar o caminho para salvar</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Formato</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Mantenha pressionada a tecla Shift para desenhar quadrados ou círculos.</transl
         <source>Select a location when saving</source>
         <translation>Selecionar uma localização ao guardar</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Captura de ecrã AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Salvar no Ambiente de trabalho</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Salvar em imagens</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
