@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sq">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Shpjegoje</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Përktheni</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Pyetni AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Përmbledhje</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <source>Change the path on save</source>
         <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Desktop</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Foto</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <source>Update the location when saving</source>
         <translation>Përditësoni vendndodhjen gjatë ruajtjes</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Desktop</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Foto</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <translation>Rregullime (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Format:</translation>
+        <source>Format</source>
+        <translation>Format</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejt
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>KPS:</translation>
+        <source>FPS</source>
+        <translation>KPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Shtypni dhe mbani të shtypur tastin Shift, që të vizatohet një shigjetë ver
         <source>Change the path on save</source>
         <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Mbani të shtypur tastin Shift që të vizatohet një drejtkëndësh ose një rr
         <source>Select a location when saving</source>
         <translation>Zgjidhni vendndodhjen gjatë ruajtjes</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>Foto ekrani AI (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Ruaje te Desktop</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Ruaje te Foto</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
