@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sr">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Објасни</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Преведи</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>Потражи ИИ</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Сажетак</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>Промени путању приликом сачувања</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Радна површина</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Слике</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -209,7 +236,7 @@ or press the shortcut again to stop recording</source>
     <name>SaveMenuManager</name>
     <message>
         <source>Each inquiry</source>
-        <translation type="unfinished">Сваки захтев</translation>
+        <translation>Сваки захтев</translation>
     </message>
     <message>
         <source>Specified location</source>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation>Промени путању приликом сачувања</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Радна површина</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Слике</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>Поставке (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Формат:</translation>
+        <source>Format</source>
+        <translation>Формат</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Change the path on save</source>
         <translation>Промени путању приликом сачувања</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Формат</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation>Постави путању приликом сачувања</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>ИИ снимак (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Сачувај на радној површини</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Сачувај у слике</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
