@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="tr">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>Açıklama</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>Çevir</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>AI&apos;ye sor</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>Özet</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <source>Change the path on save</source>
         <translation>Kaydet sırasında yolu değiştir</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Masaüstü</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Resimler</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -209,7 +236,7 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
     <name>SaveMenuManager</name>
     <message>
         <source>Each inquiry</source>
-        <translation type="unfinished">Her sorgulama</translation>
+        <translation>Her sorgulama</translation>
     </message>
     <message>
         <source>Specified location</source>
@@ -223,6 +250,14 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <source>Update the location when saving</source>
         <translation>Kaydet sırasında yolu değiştir</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>Masaüstü</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Resimler</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Düz bir çizgi çizmek için Shift tuşunu basılı tutun</translation>
         <translation>Ayarlar (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>Biçim:</translation>
+        <source>Format</source>
+        <translation>Biçim</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Düz bir çizgi çizmek için Shift tuşunu basılı tutun</translation>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>FPS:</translation>
+        <source>FPS</source>
+        <translation>FPS</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Dikey veya yatay ok çizmek için Shift tuşunu basılı tutun</translation>
         <source>Change the path on save</source>
         <translation>Kaydet sırasında yolu değiştir</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>Biçim</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Kare veya daire çizmek için Shift tuşunu basılı tutun.</translation>
         <source>Select a location when saving</source>
         <translation>Kaydet sırasında bir yol ayarla</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI Ekran Görüntüsü (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>Masaüstüne kaydet</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>Resimlere kaydet</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
