@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ug">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>تەڭشەش</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>تەڭشەش</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>تەڭشەش</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>تەڭشەش</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -151,6 +170,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>ئۈستەليۈزى</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>رەسىم</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -222,6 +249,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>ئۈستەليۈزى</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>رەسىم</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -521,8 +556,8 @@ Shift نى بېسىپ تۇرسىڭىز تۈز سىزىق سىزغىلى بولى
         <translation>تەڭشەك (F3)</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>فورماتى:</translation>
+        <source>Format</source>
+        <translation>فورماتى</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -541,8 +576,8 @@ Shift نى بېسىپ تۇرسىڭىز تۈز سىزىق سىزغىلى بولى
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>كاندۇك سانى:</translation>
+        <source>FPS</source>
+        <translation>كاندۇك سانى</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -648,10 +683,6 @@ Shift نى بېسىپ تۇرسىڭىز تىك ۋە توغرىسىغا تۈز ك
         <source>Change the path on save</source>
         <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>فورماتى</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -714,6 +745,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation>ئورۇننى ساقلىغاندا يېڭىلاش</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI تۇتۇش (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>ئۈستەليۈز ساقلاش</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>رەسىم ساقلاش</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
