@@ -1,6 +1,25 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_HK">
+<context>
+    <name>AIAssistantWidget</name>
+    <message>
+        <source>Explain</source>
+        <translation>解釋</translation>
+    </message>
+    <message>
+        <source>Translate</source>
+        <translation>翻譯</translation>
+    </message>
+    <message>
+        <source>Ask AI</source>
+        <translation>問問 AI</translation>
+    </message>
+    <message>
+        <source>Summary</source>
+        <translation>總結</translation>
+    </message>
+</context>
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -152,6 +171,14 @@ or press the shortcut again to stop recording</source>
         <source>Change the path on save</source>
         <translation>保存時更新位置</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>桌面</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>圖片</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -223,6 +250,14 @@ or press the shortcut again to stop recording</source>
         <source>Update the location when saving</source>
         <translation>保存時更新位置</translation>
     </message>
+    <message>
+        <source>Desktop</source>
+        <translation>桌面</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>圖片</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -522,8 +557,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>設定 F3</translation>
     </message>
     <message>
-        <source>Format:</source>
-        <translation>格式：</translation>
+        <source>Format</source>
+        <translation>格式</translation>
     </message>
     <message>
         <source>GIF</source>
@@ -542,8 +577,8 @@ Press and hold Shift to draw a straight line</source>
         <translation>webm</translation>
     </message>
     <message>
-        <source>FPS:</source>
-        <translation>幀數：</translation>
+        <source>FPS</source>
+        <translation>幀數</translation>
     </message>
     <message>
         <source>5 fps</source>
@@ -649,10 +684,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Change the path on save</source>
         <translation>保存時更新位置</translation>
     </message>
-    <message>
-        <source>Format</source>
-        <translation>格式</translation>
-    </message>
     <message>
         <source>PNG</source>
         <translation>PNG</translation>
@@ -715,6 +746,18 @@ Hold down Shift to draw squares or circles.</source>
         <source>Select a location when saving</source>
         <translation>保存時選擇位置</translation>
     </message>
+    <message>
+        <source>AI Screenshot (A)</source>
+        <translation>AI截圖 (A)</translation>
+    </message>
+    <message>
+        <source>Save to Desktop</source>
+        <translation>保存到桌面</translation>
+    </message>
+    <message>
+        <source>Save to Pictures</source>
+        <translation>保存到圖片</translation>
+    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
